==> kdebase-runtime-4.1.1.tar.bz2: kdebase-runtime-4.1.1/nepomuk/kcm/nepomukserverkcm.h <==
/* This file is part of the KDE Project
   Copyright (c) 2007 Sebastian Trueg <trueg@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License version 2 as published by the Free Software Foundation.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#ifndef _NEPOMUK_SERVER_KCM_H_
#define _NEPOMUK_SERVER_KCM_H_

#include <KCModule>
#include "ui_nepomukconfigwidget.h"
#include "nepomukserverinterface.h"

namespace Nepomuk {
    class ServerConfigModule : public KCModule, private Ui::NepomukConfigWidget
    {
        Q_OBJECT

    public:
        ServerConfigModule( QWidget* parent, const QVariantList& args );
        ~ServerConfigModule();

    public Q_SLOTS:
        void load();
        void save();
        void defaults();

    private Q_SLOTS:
        void updateStrigiStatus();
        void updateStrigiSettingsInRunningInstance();

    private:
        bool isStrigiRunning();

        org::kde::NepomukServer m_serverInterface;
    };
}

#endif

==> kdebase-runtime-4.4.0.tar.bz2: kdebase-runtime-4.4.0/nepomuk/kcm/nepomukserverkcm.h <==
/* This file is part of the KDE Project
   Copyright (c) 2007 Sebastian Trueg <trueg@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License version 2 as published by the Free Software Foundation.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#ifndef _NEPOMUK_SERVER_KCM_H_
#define _NEPOMUK_SERVER_KCM_H_

#include <KCModule>
#include "ui_nepomukconfigwidget.h"
#include "nepomukserverinterface.h"
#include "strigiserviceinterface.h"
#include "nepomukservicemanagerinterface.h"

class FolderSelectionModel;

namespace Nepomuk {
    class ServerConfigModule : public KCModule, private Ui::NepomukConfigWidget
    {
        Q_OBJECT

    public:
        ServerConfigModule( QWidget* parent, const QVariantList& args );
        ~ServerConfigModule();

    public Q_SLOTS:
        void load();
        void save();
        void defaults();

    private Q_SLOTS:
        void slotUpdateStrigiStatus();
        void recreateStrigiInterface();

    private:
        org::kde::NepomukServer m_serverInterface;
        org::kde::nepomuk::ServiceManager m_serviceManagerInterface;
        org::kde::nepomuk::Strigi* m_strigiInterface;

        FolderSelectionModel* m_folderModel;

        bool m_failedToInitialize;
    };
}

#endif
